@@ -1,3 +1,5 @@
+from datetime import datetime
+
 import pytest
 import json
 from astropy.io import fits
@@ -5,8 +7,12 @@ import numpy as np
 import time
 import jwt
 import os
+import random
+import string
 
 from cdci_data_analysis.analysis.json import CustomJSONEncoder
+
+import oda_api.api
 from oda_api.data_products import NumpyDataProduct
 
 secret_key = 'secretkey_test'
@@ -85,8 +91,12 @@ def test_variable_length_table():
 
 @pytest.mark.test_drupal
 @pytest.mark.parametrize("observation", ['test observation', None])
-@pytest.mark.parametrize("source_name", ['GX 1+4', None])
-def test_image_product_gallery(dispatcher_api_with_gallery, observation, source_name):
+@pytest.mark.parametrize("type_source", ["known", "new", None])
+@pytest.mark.parametrize("insert_new_source", [True, False])
+@pytest.mark.parametrize("force_insert_not_valid_new_source", [True, False])
+@pytest.mark.parametrize("validate_source", [True, False])
+@pytest.mark.parametrize("apply_fields_source_resolution", [True, False])
+def test_image_product_gallery(dispatcher_api_with_gallery, dispatcher_test_conf_with_gallery, observation, type_source, insert_new_source, force_insert_not_valid_new_source, validate_source, apply_fields_source_resolution):
     import oda_api.plot_tools as pt
 
     # let's generate a valid token
@@ -96,7 +106,15 @@ def test_image_product_gallery(dispatcher_api_with_gallery, observation, source_
     }
     encoded_token = jwt.encode(token_payload, secret_key, algorithm='HS256')
 
+    source_name = None
+    if type_source == "known":
+        source_name = "Crab"
+    elif type_source == "new":
+        source_name = "new_source_" + ''.join(random.choices(string.digits + string.ascii_lowercase, k=5))
+
     product_name = "isgri_image"
+    instrument = "isgri"
+
     par_dict = {
         "DEC": -24.7456,
         "E1_keV": 28,
@@ -108,13 +126,14 @@ def test_image_product_gallery(dispatcher_api_with_gallery, observation, source_
         "src_name": source_name,
         "max_pointings": 10,
         "detection_threshold": "7.0",
-        "instrument": "isgri",
+        "instrument": instrument,
         "integral_data_rights": "public",
         "oda_api_version": "1.1.22",
         "off_line": "False",
         "osa_version": "OSA11.1",
         "product": product_name,
         "product_type": "Dummy",
+        'token': encoded_token
     }
 
     disp = dispatcher_api_with_gallery
@@ -131,21 +150,34 @@ def test_image_product_gallery(dispatcher_api_with_gallery, observation, source_
     dec = 19
     ra = 458
 
-    res = disp.post_data_product_to_gallery(src_name=source_name,
-                                            gallery_image_path=gallery_image,
-                                            fits_file_path=fits_file,
-                                            observation_id=observation,
-                                            token=encoded_token,
-                                            e1_kev=e1_kev, e2_kev=e2_kev,
-                                            DEC=dec, RA=ra
-                                            )
+    instrument = 'isgri'
+    product_type = "isgri_image"
 
-    if source_name is None:
-        source_name = 'source'
-    prod_title = source_name + "_" + product_name
+    product_title = "_".join(
+        [instrument, product_type, datetime.fromtimestamp(time.time()).strftime("%Y-%m-%d %H:%M:%S")])
+
+    res = disp.post_data_product_to_gallery(
+        product_title=product_title,
+        instrument=instrument,
+        src_name=source_name,
+        insert_new_source=insert_new_source,
+        force_insert_not_valid_new_source=force_insert_not_valid_new_source,
+        apply_fields_source_resolution=apply_fields_source_resolution,
+        validate_source=validate_source,
+        gallery_image_path=gallery_image,
+        fits_file_path=fits_file,
+        observation_id=observation,
+        token=encoded_token,
+        e1_kev=e1_kev, e2_kev=e2_kev,
+        DEC=dec, RA=ra
+        )
+
+    if type_source == 'known' and validate_source and apply_fields_source_resolution:
+        ra = 83.63
+        dec = 22.01
 
     assert 'title' in res
-    assert res['title'][0]['value'] == prod_title
+    assert res['title'][0]['value'] == product_title
 
     assert 'field_e1_kev' in res
     assert res['field_e1_kev'][0]['value'] == e1_kev
@@ -154,10 +186,20 @@ def test_image_product_gallery(dispatcher_api_with_gallery, observation, source_
     assert res['field_e2_kev'][0]['value'] == e2_kev
 
     assert 'field_dec' in res
-    assert res['field_dec'][0]['value'] == dec
+    assert round(res['field_dec'][0]['value'], 2) == dec
 
     assert 'field_ra' in res
-    assert res['field_ra'][0]['value'] == ra
+    assert round(res['field_ra'][0]['value'], 2) == ra
+
+    link_astrophysical_entity = os.path.join(
+        dispatcher_test_conf_with_gallery['product_gallery_options']['product_gallery_url'],
+        'rest/relation/node/data_product/field_describes_astro_entity')
+    if type_source == 'known' or \
+            (type_source == 'new' and ((force_insert_not_valid_new_source and insert_new_source)
+             or (not validate_source and insert_new_source))):
+        assert link_astrophysical_entity in res['_links']
+    else:
+        assert link_astrophysical_entity not in res['_links']
 
 
 @pytest.mark.test_drupal
@@ -343,3 +385,72 @@ def test_spectrum_product_gallery(dispatcher_api_with_gallery, observation, sour
 
     assert 'field_ra' in res
     assert res['field_ra'][0]['value'] == ra
+
+
+@pytest.mark.test_drupal
+@pytest.mark.parametrize("source_name", ['Mrk 421', 'Mrk_421', 'fake object', None])
+def test_resolve_source(dispatcher_api_with_gallery, dispatcher_test_conf_with_gallery, source_name):
+    disp = dispatcher_api_with_gallery
+
+    # let's generate a valid token
+    token_payload = {
+        **default_token_payload,
+        'roles': 'general, gallery contributor'
+    }
+    encoded_token = jwt.encode(token_payload, secret_key, algorithm='HS256')
+
+    resolved_obj = disp.resolve_source(source_name, encoded_token)
+
+    if source_name is None:
+        assert resolved_obj is None
+    elif source_name == 'fake object':
+        assert 'name' in resolved_obj
+        assert 'message' in resolved_obj
+
+        # the name resolver replaces automatically underscores with spaces in the returned name
+        assert resolved_obj['name'] == source_name
+        assert 'Nothing found' in resolved_obj['message']
+    else:
+        assert 'name' in resolved_obj
+        assert 'resolver' in resolved_obj
+        assert 'DEC' in resolved_obj
+        assert 'RA' in resolved_obj
+        assert 'entity_portal_link' in resolved_obj
+
+        assert resolved_obj['name'] == source_name.replace('_', ' ')
+        assert resolved_obj['entity_portal_link'] == dispatcher_test_conf_with_gallery["product_gallery_options"]["entities_portal_url"]\
+            .format(source_name)
+
+
+@pytest.mark.test_drupal
+@pytest.mark.parametrize("product_type", ['isgri_image', 'jemx_lc', 'aaaaaa', '', None])
+@pytest.mark.parametrize("provide_source", [True, False])
+def test_check_product_type_policy(dispatcher_api_with_gallery, dispatcher_test_conf_with_gallery, product_type, provide_source):
+    disp = dispatcher_api_with_gallery
+
+    # let's generate a valid token
+    token_payload = {
+        **default_token_payload,
+        'roles': 'general, gallery contributor'
+    }
+    encoded_token = jwt.encode(token_payload, secret_key, algorithm='HS256')
+
+    par_dict = {
+        "DEC": -24.7456,
+        "E1_keV": 28,
+        "E2_keV": 50,
+        "RA": 263.0090,
+        "T1": '2012-07-03T00:00:00',
+        "T2": '2014-04-03T17:59:59',
+        "radius": 8,
+        "product_type": product_type,
+    }
+
+    if provide_source:
+        par_dict['src_name'] = 'Crab'
+
+    if product_type == 'jemx_lc' and not provide_source:
+        with pytest.raises(oda_api.api.UserError):
+            disp.check_gallery_data_product_policy(encoded_token, **par_dict)
+    else:
+        assert disp.check_gallery_data_product_policy(encoded_token, **par_dict)
